==> nextcloud-27.1.11.tgz: nextcloud/apps/activity/l10n/fi.js <==
OC.L10N.register(
    "activity",
    {
    "Personal activity feed for %s" : "Käyttäjän %s henkilökohtainen tapahtumasyöte",
    "Your feed URL is invalid" : "Syötteen osoite on virheellinen",
    "Activity feed" : "Tapahtumasyöte",
    "Your settings have been updated." : "Asetuksesi on päivitetty.",
    "Settings have been updated." : "Asetukset on päivitetty.",
    "Recent activity" : "Viimeisimmät tapahtumat",
    "No activities" : "Ei tapahtumia",
    "More activities" : "Lisää tapahtumia",
    "Daily activity summary for %s" : "Päivittäisten toimien yhteenveto%s lle",
    "_and %n more _::_and %n more _" : ["ja %n lisää","ja %n lisää"],
    "All activities" : "Kaikki tapahtumat",
    "By others" : "Muiden tapahtumat",
    "By you" : "Omat tapahtumat",
    "Activity at %s" : "Tapahtuma - %s",
    "Hello %s" : "Hei %s",
    "Hello %s," : "Hei %s,",
    "There was some activity at %s" : "%s sisältää joitain uusia tapahtumia",
    "Mail" : "Sähköposti",
    "Push" : "Push",
    "Activity" : "Tapahtumat",
    "Notifications" : "Ilmoitukset",
    "Activity notification configuration" : "Tapahtumien ilmoitusasetukset",
    "Send email" : "Lähetä sähköposti",
    "Send push notification" : "Lähetä push-ilmoituksia",
    "Today" : "Tänään",
    "Yesterday" : "Eilen",
    "You need to set up your email address before you can receive notification emails." : "Aseta sähköpostiosoite, jotta voit vastaanottaa sähköposti-ilmoituksia.",
    "Send activity emails" : "Lähetä tapahtumasähköposteja",
    "As soon as possible" : "Heti kuin mahdollista",
    "Hourly" : "Tunneittain",
    "Daily" : "Päivittäin",
    "Weekly" : "Viikottain",
    "You commented" : "Kommentoit",
    "Open {filename}" : "Avaa {filename}",
    "in {path}" : "polussa {path}",
    "Home" : "Koti",
    "Loading activities" : "Ladataan tapahtumia",
    "This stream will show events like additions, changes & shares" : "Tähän ilmestyy tapahtumavirta, joka näyttää lisäys-, muutos- ja jakotapahtumia",
    "No activity yet" : "Ei vielä tapahtumia",
    "Loading more activities" : "Ladataa lisää tapahtumia",
    "No more activities." : "Ei enempää tapahtumia.",
    "Activity settings" : "Tapahtumien asetukset",
    "Enable RSS feed" : "Ota RSS-syöte käyttöön",
    "RSS feed" : "RSS-syöte",
    "Copy RSS feed link" : "Kopioi RSS-syötteen linkki",
    "Personal notification settings" : "Henkilökohtaisten ilmoitusten asetukset",
    "Could not enable RSS link" : "RSS-linkkiä ei voitu ottaa käyttöön",
    "RSS link copied to clipboard" : "RSS-linkki kopioitu leikepöydälle",
    "Unable to load the activity list" : "Tapahtumalistan lataaminen ei onnistu",
    "Notification" : "Ilmoitus",
    "Enable notification emails" : "Käytä ilmoitussähköposteja",
    "Choose for which activities you want to get an email or push notification." : "Valitse toiminnat, joista haluat sähköposti- tai Push-ilmoituksen.",
    "Choose for which activities you want to get a push notification." : "Valitse toiminnat, joista haluat Push-ilmoituksen.",
    "Daily activity summary" : "Päivittäinen yhteenveto tapahtumista",
    "Send daily activity summary in the morning" : "Lähetä aamuisin päivittäisyhteenveto toiminnoista ",
    "Default settings" : "Oletusasetukset",
    "Configure the default notification settings for new accounts." : "Määritä uusien tilien oletusarvoiset ilmoitusasetukset.",
    "Unable to save the settings" : "Asetusten tallentaminen epäonnistui",
    "No more events to load" : "Ei enempää tapahtumia",
    "Copied!" : "Kopioitu!",
    "Not supported!" : "Ei tuettu!",
    "Press ⌘-C to copy." : "Paina ⌘-C kopioidaksesi.",
    "Press Ctrl-C to copy." : "Paina Ctrl-C kopioidaksesi.",
    "{name} (invisible)" : "{name} (näkymätön)",
    "{name} (restricted)" : "{name} (rajoitettu)",
    "There are no events for this filter" : "Tällä suodattimella ei löydy tapahtumia",
    "Could not load activites" : "Tapahtumia ei voitu ladata"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-28.0.8.tgz: nextcloud/apps/activity/l10n/fi.js <==
OC.L10N.register(
    "activity",
    {
    "Personal activity feed for %s" : "Käyttäjän %s henkilökohtainen tapahtumasyöte",
    "Your feed URL is invalid" : "Syötteen osoite on virheellinen",
    "Activity feed for %1$s" : "%1$s:n tapahtumasyöte",
    "Activity feed" : "Tapahtumasyöte",
    "Your settings have been updated." : "Asetuksesi on päivitetty.",
    "Settings have been updated." : "Asetukset on päivitetty.",
    "Recent activity" : "Viimeisimmät tapahtumat",
    "No activities" : "Ei tapahtumia",
    "More activities" : "Lisää tapahtumia",
    "Daily activity summary for %s" : "Päivittäisten tapahtumien yhteenveto%s lle",
    "All activities" : "Kaikki tapahtumat",
    "By others" : "Muiden tapahtumat",
    "By you" : "Omat tapahtumat",
    "Activity at %s" : "Tapahtuma - %s",
    "Hello %s" : "Hei %s",
    "Hello %s," : "Hei %s,",
    "There was some activity at %s" : "%s sisältää joitain uusia tapahtumia",
    "_and %n more _::_and %n more _" : ["ja %n lisää","ja %n lisää"],
    "Mail" : "Sähköposti",
    "Push" : "Push",
    "Activity" : "Tapahtumat",
    "Notifications" : "Ilmoitukset",
    "This application enables people to view a log of activities about them, their files or other data." : "Tämä sovellus mahdollistaa käyttäjien tarkastelevan heitä, heidän tiedostojaan tai muuta dataa koskevia tapahtumia.",
    "This app allows people to see actions related to their files and data in Nextcloud.\n\t\tEach person can configure their individual activity settings in the personal settings,\n\t\tto choose which activity should be pushed to mobile phones, sent via email\n\t\tor whether a daily summary is sent each morning.\n\t\tMore information is available in the Activity documentation." : "Tämä sovellus mahdollistaa käyttäjien nähdä tiedostojaan ja dataansa koskevia tapahtumia Nextcloudissa.\n\t\tKukin käyttäjä voi muuttaa yksittäisiä asetuksia henkilökohtaisista asetuksista,\n\t\tvalita matkaviestimessä näytettävät tai sähköpostiin lähetettävät tapahtumailmoitukset,\n\t\tsekä valita lähetetäänkö päivittäinen kooste aamulla.\n\t\tVoit lukea lisätietoja Tapahtumat -dokumentaatiosta.",
    "Activity notification configuration" : "Tapahtumien ilmoitusasetukset",
    "Send email" : "Lähetä sähköposti",
    "Send push notification" : "Lähetä push-ilmoituksia",
    "Today" : "Tänään",
    "Yesterday" : "Eilen",
    "You need to set up your email address before you can receive notification emails." : "Aseta sähköpostiosoite, jotta voit vastaanottaa sähköposti-ilmoituksia.",
    "Send activity emails" : "Lähetä tapahtumasähköposteja",
    "As soon as possible" : "Heti kuin mahdollista",
    "Hourly" : "Tunneittain",
    "Daily" : "Päivittäin",
    "Weekly" : "Viikottain",
    "You commented" : "Kommentoit",
    "Message deleted by author" : "Viestin lähettäjä poisti viestin",
    "Open {filename}" : "Avaa {filename}",
    "in {path}" : "polussa {path}",
    "Home" : "Koti",
    "Loading activities" : "Ladataan tapahtumia",
    "This stream will show events like additions, changes & shares" : "Tähän ilmestyy tapahtumavirta, joka näyttää lisäys-, muutos- ja jakotapahtumia",
    "No activity yet" : "Ei vielä tapahtumia",
    "Loading more activities" : "Ladataa lisää tapahtumia",
    "No more activities." : "Ei enempää tapahtumia.",
    "Could not load activities" : "Tapahtumia ei voida ladata",
    "Activity settings" : "Tapahtumien asetukset",
    "Enable RSS feed" : "Ota RSS-syöte käyttöön",
    "RSS feed" : "RSS-syöte",
    "Copy RSS feed link" : "Kopioi RSS-syötteen linkki",
    "Personal notification settings" : "Henkilökohtaisten ilmoitusten asetukset",
    "Could not enable RSS link" : "RSS-linkkiä ei voitu ottaa käyttöön",
    "RSS link copied to clipboard" : "RSS-linkki kopioitu leikepöydälle",
    "Could not copy the RSS link, please copy manually:" : "RSS-linkkiä ei voitu kopioida, kopioi se manuaalisesti:",
    "Unable to load the activity list" : "Tapahtumalistan lataaminen ei onnistu",
    "Notification" : "Ilmoitus",
    "Enable notification emails" : "Käytä ilmoitussähköposteja",
    "Choose for which activities you want to get an email or push notification." : "Valitse toiminnat, joista haluat sähköposti- tai Push-ilmoituksen.",
    "Choose for which activities you want to get a push notification." : "Valitse toiminnat, joista haluat Push-ilmoituksen.",
    "Daily activity summary" : "Päivittäinen yhteenveto tapahtumista",
    "Send daily activity summary in the morning" : "Lähetä aamuisin päivittäinen yhteenveto toiminnoista ",
    "Default settings" : "Oletusasetukset",
    "Configure the default notification settings for new accounts." : "Määritä uusien tilien oletusarvoiset ilmoitusasetukset.",
    "Unable to save the settings" : "Asetusten tallentaminen epäonnistui",
    "No more events to load" : "Ei enempää tapahtumia",
    "Copied!" : "Kopioitu!",
    "Not supported!" : "Ei tuettu!",
    "Press ⌘-C to copy." : "Paina ⌘-C kopioidaksesi.",
    "Press Ctrl-C to copy." : "Paina Ctrl-C kopioidaksesi.",
    "{name} (invisible)" : "{name} (näkymätön)",
    "{name} (restricted)" : "{name} (rajoitettu)",
    "There are no events for this filter" : "Tällä suodattimella ei löydy tapahtumia",
    "Could not load activites" : "Tapahtumia ei voitu ladata"
},
"nplurals=2; plural=(n != 1);");
